Client

Struct Client 

pub struct Client(pub Client);
A Liquid RPC client.

This type implements both the bitcoincore_rpc::RpcApi trait as the [liquid_rpc::LiquidRpcApi] trait. Methods that are shared between Liquid and Bitcoin Core can be used from the former and changed or new methods are provided by the latter.

Tuple Fields

0: Client

Implementations

Source

impl Client

pub fn new(url: String, auth: Auth) -> Result<Self>

Creates a client to a liquidd JSON-RPC server.

pub fn from_jsonrpc(client: Client) -> Self

Create a new Client.